import Image from "next/image";

import { getLocale, getTranslations } from "next-intl/server";

import LanguageSwitcherSelect from "@/components/common/testings/language-switcher-select";
import VerifyForm from "@/components/sections/auth/verify-form";
import { Link, routing } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import Cookies from "js-cookie";

const ImageSection = () => {

	return (
		<>
			<Image
				src="/images/shared/bin-taleb-flag.jpeg"
				alt="Bin Taleb Flag"
				fill
				style={{ objectFit: "cover" }}
				priority
			/>

			<div className="absolute bottom-10 left-1/2 z-20 -translate-x-1/2 text-center">
				<p
					dir="rtl"
					className="mb-3.5 whitespace-nowrap text-xl font-semibold text-[#FAFAFA]"
				>
					شركة عبدالله بن طالب لبرك السباحة
				</p>
				<p
					dir="ltr"
					className="whitespace-nowrap text-xl font-semibold text-[#FAFAFA]"
				>
					A.bin taleb swimming pools co.
				</p>
			</div>

			<div className="absolute left-0 top-0 z-10 h-full w-full bg-[#0000005E]" />
		</>
	);
};

const FormSection = async () => {
	const lang = await getLocale();
	const t = await getTranslations("Auth");
	const phone = Cookies.get("__p");

	console.log("phone: ", phone);
	return (
		<>
			<div className="flex w-full flex-col items-center p-14 text-white md:w-fit">
				{/*//TODO LOGO */}
				<div
					className="flex h-28 w-28 items-center justify-center rounded-full bg-custom-background-light"
					style={{
						boxShadow: "0px 4px 4px 0px #00000040",
					}}
				>
					<Link href={"/" as any}>
						<Image
							src="/logo-footer.png"
							alt="Bin Taleb Flag"
							width={80}
							height={99}
							style={{
								width: "80px",
								height: "99px",
								objectFit: "contain",
							}}
							priority
						/>
					</Link>
				</div>

				<div className="mb-4 text-center">
					<p className="text-[32px] leading-[60px] md:text-[52px] md:leading-[90px]">
						{t("Verify")}
					</p>
					<p className="text-lg leading-[38.12px]">{t("DescriptionVerifyForm")}</p>
					<p className={cn("text-md leading-[38.12px]")} dir="ltr">{`+966******${phone?.slice(6) ?? "***"}`}</p>
				</div>

				<VerifyForm />
				<LanguageSwitcherSelect
					icon={true}
					defaultValue={lang}
					label="Select a locale"
				>
					{routing.locales?.map((cur) => (
						<option key={cur} value={cur}>
							<p className="text-xs text-custom-background-light sm:text-sm">
								{cur == "ar" ? "العربية" : "English"}
							</p>
						</option>
					))}
				</LanguageSwitcherSelect>
			</div>
			<div
				className={`absolute top-0 hidden md:block ${lang == "ar" ? "-left-14 rounded-bl-[40px] rounded-tl-[40px]" : "-right-14 rounded-br-[40px] rounded-tr-[40px]"} z-40 h-full w-14 bg-gradient-blue`}
			/>
		</>
	);
};

export default async function VerifyPage() {

	return (
		<section>
			<div className="flex min-h-screen w-full justify-center">
				<div className="relative flex flex-1 items-center justify-center bg-gradient-blue md:flex-[45%] md:items-start">
					<FormSection />
				</div>
				<div className="relative hidden flex-[55%] md:block">
					<ImageSection />
				</div>
			</div>
		</section>
	);
}
